==> owncloud-9.0.4-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/es_AR.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "No se pudieron mandar correos a los siguientes usuarios: %s",
    "Turned on maintenance mode" : "Modo de mantenimiento activado",
    "Turned off maintenance mode" : "Modo de mantenimiento desactivado",
    "Updated database" : "Base de datos actualizada",
    "No image or file provided" : "No se ha proveído de una imágen o archivo.",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay una imágen temporal del perfil disponible, intente de nuevo",
    "No crop data provided" : "No se proveyeron datos de recorte",
    "%s password reset" : "%s restablecer contraseña",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "miér.",
    "Thu." : "jue.",
    "Fri." : "vie.",
    "Sat." : "sáb.",
    "January" : "enero",
    "February" : "febrero",
    "March" : "marzo",
    "April" : "abril",
    "May" : "mayo",
    "June" : "junio",
    "July" : "julio",
    "August" : "agosto",
    "September" : "septiembre",
    "October" : "octubre",
    "November" : "noviembre",
    "December" : "diciembre",
    "Jan." : "ene.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "may.",
    "Jun." : "jun.",
    "Jul." : "jul.",
    "Aug." : "ago.",
    "Sep." : "sep.",
    "Oct." : "oct.",
    "Nov." : "nov.",
    "Dec." : "dic.",
    "Settings" : "Configuración",
    "Saving..." : "Guardando...",
    "seconds ago" : "segundos atrás",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Elegir",
    "Error loading file picker template: {error}" : "Error cargando la plantilla del selector de archivo: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando la plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["un archivo en conflicto","{count} archivos en conflicto"],
    "One file conflict" : "Un archivo en conflicto",
    "New Files" : "Nuevos archivos",
    "Which files do you want to keep?" : "¿Qué archivos deseas retener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si tu seleccionas ambas versiones, el archivo copiado tendrá un número agregado a su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos están seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando la plantilla de archivo existente",
    "Very weak password" : "Contraseña muy débil.",
    "Weak password" : "Contraseña débil.",
    "So-so password" : "Contraseña de nivel medio. ",
    "Good password" : "Buena contraseña. ",
    "Strong password" : "Contraseña fuerte.",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error en al dejar de compartir",
    "Error setting expiration date" : "Error al asignar fecha de vencimiento",
    "Set expiration date" : "Asignar fecha de vencimiento",
    "Expiration" : "Vencimiento",
    "Expiration date" : "Fecha de vencimiento",
    "Sending ..." : "Mandando...",
    "Email sent" : "e-mail mandado",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Share link" : "Compartir vínculo",
    "Password protect" : "Proteger con contraseña ",
    "Password" : "Contraseña",
    "Email link to person" : "Enviar el enlace por e-mail.",
    "Send" : "Mandar",
    "Shared with you and the group {group} by {owner}" : "Compartido con vos y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vos por {owner}",
    "group" : "grupo",
    "notify by email" : "notificar por correo",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "podés editar",
    "create" : "crear",
    "delete" : "borrar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Warning" : "Atención",
    "Delete" : "Borrar",
    "Rename" : "Cambiar nombre",
    "The object type is not specified." : "El tipo de objeto no está especificado. ",
    "Enter new" : "Entrar nuevo",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando la plantilla de dialogo: {error}",
    "No tags selected for deletion." : "No se han seleccionado etiquetas para eliminar.",
    "Please reload the page." : "Por favor, recargue la página.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización fue exitosa. Estás siendo redirigido a ownCloud.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Apps",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Error loading tags" : "Error cargando las etiquetas",
    "Tag already exists" : "La etiqueta ya existe",
    "Error deleting tag(s)" : "Error borrando etiquetas(s)",
    "Error tagging" : "Error al etiquetar",
    "Error untagging" : "Error al sacar la etiqueta",
    "Error favoriting" : "Error al favorecer",
    "Error unfavoriting" : "Error al desfavorecer",
    "Access forbidden" : "Acceso prohibido",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "¡Hola!\n\nsólo te quería decir que %s acaba de compartir %s contigo.\nVerlo: %s\n\n",
    "The share will expire on %s." : "El compartir expirará en %s.",
    "Cheers!" : "¡Saludos!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y tus archivos probablemente son accesibles a través de internet, ya que el archivo .htaccess no está funcionando.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para información sobre cómo configurar apropiadamente tu servidor, por favor mirá la <a href=\"%s\" target=\"_blank\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Data folder" : "Directorio de almacenamiento",
    "Configure the database" : "Configurar la base de datos",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Huésped de la base de datos",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando...",
    "Log out" : "Cerrar la sesión",
    "Search" : "Buscar",
    "Server side authentication failed!" : "¡Falló la autenticación del servidor!",
    "Please contact your administrator." : "Por favor, contacte a su administrador.",
    "Log in" : "Iniciar sesión",
    "Alternative Logins" : "Nombre alternativos de usuarios",
    "Use the following link to reset your password: {link}" : "Usá este enlace para restablecer tu contraseña: {link}",
    "New password" : "Nueva contraseña:",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instancia de ownCloud está en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto significa que solo administradores pueden usar esta instancia.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte su administrador de sistema si este mensaje persiste o aparece inesperadamente.",
    "Thank you for your patience." : "Gracias por su paciencia.",
    "Error loading file picker template: {error}" : "Error cargando la plantilla del selector de archivo: {error}",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y tus archivos probablemente son accesibles a través de internet, ya que el archivo .htaccess no está funcionando."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/es_AR.js <==
OC.L10N.register(
    "core",
    {
    "No image or file provided" : "No se ha proveído de una imágen o archivo.",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "No temporary profile picture available, try again" : "No hay una imágen temporal del perfil disponible, intente de nuevo",
    "No crop data provided" : "No se proveyeron datos de recorte",
    "%s password reset" : "%s restablecer contraseña",
    "Error loading tags" : "Error cargando las etiquetas",
    "Tag already exists" : "La etiqueta ya existe",
    "Error deleting tag(s)" : "Error borrando etiquetas(s)",
    "Error tagging" : "Error al etiquetar",
    "Error untagging" : "Error al sacar la etiqueta",
    "Error favoriting" : "Error al favorecer",
    "Error unfavoriting" : "Error al desfavorecer",
    "Couldn't send mail to following users: %s " : "No se pudieron mandar correos a los siguientes usuarios: %s",
    "Turned on maintenance mode" : "Modo de mantenimiento activado",
    "Turned off maintenance mode" : "Modo de mantenimiento desactivado",
    "Updated database" : "Base de datos actualizada",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "miér.",
    "Thu." : "jue.",
    "Fri." : "vie.",
    "Sat." : "sáb.",
    "January" : "enero",
    "February" : "febrero",
    "March" : "marzo",
    "April" : "abril",
    "May" : "mayo",
    "June" : "junio",
    "July" : "julio",
    "August" : "agosto",
    "September" : "septiembre",
    "October" : "octubre",
    "November" : "noviembre",
    "December" : "diciembre",
    "Jan." : "ene.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "may.",
    "Jun." : "jun.",
    "Jul." : "jul.",
    "Aug." : "ago.",
    "Sep." : "sep.",
    "Oct." : "oct.",
    "Nov." : "nov.",
    "Dec." : "dic.",
    "Settings" : "Configuración",
    "Saving..." : "Guardando...",
    "seconds ago" : "segundos atrás",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Elegir",
    "Error loading file picker template: {error}" : "Error cargando la plantilla del selector de archivo: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error cargando la plantilla del mensaje: {error}",
    "_{count} file conflict_::_{count} file conflicts_" : ["un archivo en conflicto","{count} archivos en conflicto"],
    "One file conflict" : "Un archivo en conflicto",
    "New Files" : "Nuevos archivos",
    "Which files do you want to keep?" : "¿Qué archivos deseas retener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si tu seleccionas ambas versiones, el archivo copiado tendrá un número agregado a su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(todos están seleccionados)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando la plantilla de archivo existente",
    "Very weak password" : "Contraseña muy débil.",
    "Weak password" : "Contraseña débil.",
    "So-so password" : "Contraseña de nivel medio. ",
    "Good password" : "Buena contraseña. ",
    "Strong password" : "Contraseña fuerte.",
    "Shared" : "Compartido",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error en al dejar de compartir",
    "Error setting expiration date" : "Error al asignar fecha de vencimiento",
    "Set expiration date" : "Asignar fecha de vencimiento",
    "Expiration" : "Vencimiento",
    "Expiration date" : "Fecha de vencimiento",
    "Resharing is not allowed" : "No se permite volver a compartir",
    "Share link" : "Compartir vínculo",
    "Password protect" : "Proteger con contraseña ",
    "Password" : "Contraseña",
    "Email link to person" : "Enviar el enlace por e-mail.",
    "Send" : "Mandar",
    "Sending ..." : "Mandando...",
    "Email sent" : "e-mail mandado",
    "Shared with you and the group {group} by {owner}" : "Compartido con vos y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido con vos por {owner}",
    "group" : "grupo",
    "notify by email" : "notificar por correo",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "podés editar",
    "create" : "crear",
    "delete" : "borrar",
    "access control" : "control de acceso",
    "Share" : "Compartir",
    "Warning" : "Atención",
    "Delete" : "Borrar",
    "Rename" : "Cambiar nombre",
    "The object type is not specified." : "El tipo de objeto no está especificado. ",
    "Enter new" : "Entrar nuevo",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error cargando la plantilla de dialogo: {error}",
    "No tags selected for deletion." : "No se han seleccionado etiquetas para eliminar.",
    "Please reload the page." : "Por favor, recargue la página.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La actualización no pudo ser completada. Por favor, reportá el inconveniente a la comunidad <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización fue exitosa. Estás siendo redirigido a ownCloud.",
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Apps",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Access forbidden" : "Acceso prohibido",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "¡Hola!\n\nsólo te quería decir que %s acaba de compartir %s contigo.\nVerlo: %s\n\n",
    "The share will expire on %s." : "El compartir expirará en %s.",
    "Cheers!" : "¡Saludos!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y tus archivos probablemente son accesibles a través de internet, ya que el archivo .htaccess no está funcionando.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Data folder" : "Directorio de almacenamiento",
    "Configure the database" : "Configurar la base de datos",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Huésped de la base de datos",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando...",
    "Log out" : "Cerrar la sesión",
    "Search" : "Buscar",
    "Server side authentication failed!" : "¡Falló la autenticación del servidor!",
    "Please contact your administrator." : "Por favor, contacte a su administrador.",
    "Log in" : "Iniciar sesión",
    "Alternative Logins" : "Nombre alternativos de usuarios",
    "Use the following link to reset your password: {link}" : "Usá este enlace para restablecer tu contraseña: {link}",
    "New password" : "Nueva contraseña:",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instancia de ownCloud está en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto significa que solo administradores pueden usar esta instancia.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte su administrador de sistema si este mensaje persiste o aparece inesperadamente.",
    "Thank you for your patience." : "Gracias por su paciencia."
},
"nplurals=2; plural=(n != 1);");
